@@ -1,9 +1,9 @@
 package App::instopt;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-22'; # DATE
+our $DATE = '2021-04-24'; # DATE
 our $DIST = 'App-instopt'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -771,19 +771,19 @@ sub cleanup_install_dir {
     for my $row (@{ $res->[2] }) {
         my $sw = $row->{software};
         log_trace "Skipping software $sw because there is no active version"
-            unless defined $row->{active_version};
-        next unless defined $row->{inactive_versions};
+            unless defined $row->{installed_active_version};
+        next unless defined $row->{installed_inactive_versions};
         #log_trace "Cleaning up software $sw ...";
-        for my $v (split /, /, $row->{inactive_versions}) {
+        for my $v (split /, /, $row->{installed_inactive_versions}) {
             my $dir = "$sw-$v";
             unless (-d $dir) {
                 log_trace "Skipping version $v of software $sw (directory does not exist)";
                 next;
             }
             if ($args{-dry_run}) {
-                log_trace "[DRY-RUN] Removing $dir ...";
+                log_info "[DRY-RUN] Removing $dir ...";
             } else {
-                log_trace "Removing $dir ...";
+                log_info "Removing $dir ...";
                 File::Path::remove_tree($dir);
             }
         }
@@ -824,9 +824,9 @@ sub cleanup_download_dir {
           VER:
             for my $v (@vers) {
                 if ($args{-dry_run}) {
-                    log_trace "[DRY-RUN] Cleaning up $sw-$v arch $arch ...";
+                    log_info "[DRY-RUN] Cleaning up $sw-$v arch $arch ...";
                 } else {
-                    log_trace "Cleaning up software $sw-$v arch $arch ...";
+                    log_info "Cleaning up software $sw-$v arch $arch ...";
                     File::Path::remove_tree("$v/$arch");
                 }
             }
@@ -1117,7 +1117,7 @@ App::instopt - Download and install software
 
 =head1 VERSION
 
-This document describes version 0.018 of App::instopt (from Perl distribution App-instopt), released on 2021-04-22.
+This document describes version 0.019 of App::instopt (from Perl distribution App-instopt), released on 2021-04-24.
 
 =head1 SYNOPSIS
 
@@ -1539,7 +1539,7 @@ Result:
          func    => "Perinci::Access::Schemeless::action_call",
          line    => 494,
          package => "Perinci::Access::Schemeless",
-         time    => 1619056032,
+         time    => 1619270870,
          type    => "create",
        },
      ],
